@@ -1,5 +1,8 @@
 bcontSurvG <- function(params, respvec, VC, ps, AT = FALSE){
 
+    monP <- monP1 <- k1 <- k2 <- 0; Veq1 <- Veq2 <- list()  
+    monP2 <- matrix(0, length(params),length(params))
+   
     epsilon <- 0.0000001 
     rotConst <- 1
 
@@ -17,8 +20,7 @@ bcontSurvG <- function(params, respvec, VC, ps, AT = FALSE){
     Xd1P <- VC$Xd1%*%params1  
     Xd2P <- VC$Xd2%*%params2
   
-    Xd1P <- ifelse(Xd1P < 1e-08, 1e-08, Xd1P ) # safety thing, never used as per model definition
-    Xd2P <- ifelse(Xd2P < 1e-08, 1e-08, Xd2P ) # safety thing, never used as per model definition
+
   
     etad <- etas1 <- etas2 <- l.ln <- NULL 
  
@@ -31,7 +33,50 @@ if( !is.null(VC$X3) ){
         X3 <- VC$X3
         teta.st <- etad <- X3%*%params[(VC$X1.d2 + VC$X2.d2 + 1):(VC$X1.d2 + VC$X2.d2 + VC$X3.d2)]
                       }
+
+##################
+
+    indNeq1 <- as.numeric(Xd1P < 0)
+    indNeq2 <- as.numeric(Xd2P < 0)
+  
+    Xd1P <- ifelse(Xd1P < 1e-06, 1e-06, Xd1P ) 
+    Xd2P <- ifelse(Xd2P < 1e-06, 1e-06, Xd2P ) 
+
+##################
+
+    if( any(indNeq1 == TRUE) && !is.null(VC$indexTeq1) ){
+        
+         k1 <- VC$my.env$k1
+
+         for(i in 1:length(VC$pos.pbeq1)){
+
+           Veq1[[i]] <- as.numeric(diff(params1[ VC$pos.pbeq1[[i]] ]) < 0)
+           monP2[ VC$pos.pbeq1[[i]], VC$pos.pbeq1[[i]] ] <- k1*t(VC$Deq1[[i]]*Veq1[[i]])%*%VC$Deq1[[i]]
  
+                                       }      
+         VC$my.env$k1 <- k1*2
+ 
+   }
+   
+    if( any(indNeq2 == TRUE) && !is.null(VC$indexTeq2) ){
+        
+         k2 <- VC$my.env$k2
+
+         for(i in 1:length(VC$pos.pbeq2)){
+
+           Veq2[[i]] <- as.numeric(diff(params2[ VC$pos.pbeq2[[i]] ]) < 0)
+           monP2[ (VC$X1.d2 + VC$pos.pbeq2[[i]]), (VC$X1.d2 + VC$pos.pbeq2[[i]]) ] <- k2*t(VC$Deq2[[i]]*Veq2[[i]])%*%VC$Deq2[[i]]
+ 
+                                       }      
+         VC$my.env$k2 <- k2*2
+ 
+   }
+   
+
+     monP  <- 0.5*crossprod(params, monP2)%*%params 
+     monP1 <- monP2%*%params 
+     
+         
 ##################
 ## Transformations
 ##################
@@ -500,20 +545,18 @@ crossprod(VC$weights*VC$c00*c(rotConst*(-p00^-2*c.copula.be2*c.copula.thet + p00
 
 if(VC$extra.regI == "pC") H <- regH(H, type = 1)
    
-  S.h  <- ps$S.h  
-  
-  if( length(S.h) != 1){
-  
-  S.h1 <- 0.5*crossprod(params,S.h)%*%params # as(S.h, "sparseMatrix") not sure about advantage...
-  S.h2 <- S.h%*%params
-  
-  } else S.h <- S.h1 <- S.h2 <- 0   
+S.h  <- ps$S.h + monP2                                # hess
+S.h1 <- 0.5*crossprod(params, ps$S.h)%*%params + monP # lik
+S.h2 <- S.h%*%params + monP1                          # grad   
   
   S.res <- res
   res   <- S.res + S.h1
   G     <- G + S.h2
   H     <- H + S.h  
-            
+      
+      
+      
+      
 if(VC$extra.regI == "sED") H <- regH(H, type = 2)   
   
 
@@ -525,10 +568,11 @@ if(VC$extra.regI == "sED") H <- regH(H, type = 2)
               dl.dbe2          = NULL,       
               dl.dteta.st      = NULL, 
               teta.ind2 = teta.ind2, teta.ind1 = teta.ind1,
-              Cop1 = Cop1, Cop2 = Cop2, teta1 = teta1, teta2 = teta2) 
+              Cop1 = Cop1, Cop2 = Cop2, teta1 = teta1, teta2 = teta2,
+              indNeq1 = indNeq1, indNeq2 = indNeq2,
+              Veq1 = Veq1, Veq2 = Veq2, 
+              k1 = VC$my.env$k1, k2 = VC$my.env$k2, monP2 = monP2) 
               
-              
-
   }
   
 
