@@ -437,16 +437,8 @@ if(gc.l == TRUE) gc()
   ##########################################################################################################################
 
 
-e.v <- round(min(eigen(SemiParFit$fit$hessian, symmetric=TRUE, only.values = TRUE)$values), 6)
-gradi <- round(max(abs(SemiParFit$fit$gradient)),1)
+cov.c(SemiParFit)
 
-me1 <- "Largest absolute gradient value is not close to 0."
-me2 <- "Information matrix is not positive definite."
-me3 <- "Read the WARNINGS section in ?gamlss."
-
-if(gradi > 10 && e.v < 0){ warning(me1, call. = FALSE); warning(paste(me2,"\n",me3), call. = FALSE)} 
-if(gradi > 10 && e.v > 0)   warning(paste(me1,"\n",me3), call. = FALSE)
-if(gradi < 10 && e.v < 0)  warning(paste(me2,"\n",me3), call. = FALSE)
 
   ##########################################################################################################################
 
@@ -504,7 +496,7 @@ L <- list(fit = SemiParFit$fit, dataset = NULL, n = n, formula = formula,
           ygrid = ygrid,
           r.weights = SemiParFit$fit$d.psi, surv = surv, surv.flex = surv.flex)
 
-class(L) <- c("gamlss","SemiParBIV")
+class(L) <- c("gamlss","SemiParBIV","gjrm")
 
 
 L
