@@ -3,6 +3,7 @@ jc.probs2 <- function(x, y1, y2, newdata, type, cond, intervals, n.sim, prob.lev
 epsilon <- 0.0000001 
 nu1 <- nu2 <- nu <- sigma2 <- 1
 CIp12 <- NULL
+CIkt <- tau <- NULL
 dof <- x$dof
 
 p12s <- NULL
@@ -227,7 +228,15 @@ if(cond == 1) p12 <- p12/p1
 if(cond == 2) p12 <- p12/pdf2
 
            }
-       
+ 
+ 
+ 
+ 
+ 
+ 
+
+ 
+ 
 }#*#
 
 
@@ -237,7 +246,10 @@ if(cond == 2) p12 <- p12/pdf2
 
 
 
+# kendalls' tau
 
+if(x$BivD %in% x$BivD2)    tau <- Reg2Copost(x$SemiParFit, x$VC, theta)$tau 
+if(!(x$BivD %in% x$BivD2)) tau <- ass.ms(x$VC$BivD, x$VC$nCa, theta)$tau 
 
 
 
@@ -501,7 +513,53 @@ if(cond == 2) p12s <- p12s/pdf2s
        
 }#*# 
  
-           
+   
+   
+   
+   
+   
+   
+   
+   
+
+nCa   <- x$VC$nCa
+BivDt <- x$VC$BivD
+
+  if(x$BivD %in% x$BivD2){
+  
+  if(x$BivD %in% x$BivD2[1:4]) { BivDt <- "C0"; nCa <- 3} 
+  if(x$BivD %in% x$BivD2[5:8]) { BivDt <- "J0"; nCa <- 6}
+  if(x$BivD %in% x$BivD2[9:12]){ BivDt <- "G0"; nCa <- 4}
+  
+                         }
+  
+ass.msR <- ass.ms(BivDt, nCa, est.RHOb)
+taus    <- ass.msR$tau
+if(!is.null(x$X3) && BivDt %in% c("AMH", "FGM")) taus <- matrix(taus, nrow(x$X3), nrow(bs))
+CIkt <- rowQuantiles(taus, probs = c(prob.lev/2,1-prob.lev/2), na.rm = TRUE)
+#if( is.null(x$X3) ) CIkt <- t(CIkt) 
+
+
+
+ if(x$BivD %in% x$BivD2){ 
+ 
+   if(length(x$theta) > 1){
+ 
+     if( length(x$teta2) != 0) CIkt[x$teta.ind2, ] <- -CIkt[x$teta.ind2, ]; CIkt[x$teta.ind2, c(1,2)] <- CIkt[x$teta.ind2, c(2,1)] 
+                                 
+                          }else{
+ 
+     if( length(x$teta2) != 0) CIkt <- -CIkt; CIkt[, c(1,2)] <- CIkt[, c(2,1)]
+                                 
+                                }
+ }
+
+   
+   
+   
+   
+   
+   
 
 } # int
 
@@ -755,7 +813,7 @@ if(cond == 2) p12s <- p1s
 } # indep
 
 
-list(p12 = p12, p12s = p12s, p1 = p1, p2 = p2, p3 = NULL)
+list(p12 = p12, p12s = p12s, p1 = p1, p2 = p2, p3 = NULL, CIkt = CIkt, tau = tau)
 
 
 }
